@@ -6,7 +6,7 @@
 ;; Maintainer: Logos Development <~protesilaos/logos@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/logos
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/logos
-;; Version: 0.5.0
+;; Version: 0.5.1
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, focus, writing, presentation, narrowing
 
@@ -60,8 +60,9 @@
 ;;
 ;; Logos provides some optional aesthetic tweaks which come into effect
 ;; when the buffer-local `logos-focus-mode' is enabled.  These will hide
-;; the mode line (`logos-hide-mode-line'), disable the buffer boundary
-;; indicators (`indicate-buffer-boundaries'), enable `scroll-lock-mode'
+;; the cursor (`logos-hide-cursor'), hide the mode line
+;; (`logos-hide-mode-line'), disable the buffer boundary indicators
+;; (`indicate-buffer-boundaries'), enable `scroll-lock-mode'
 ;; (`logos-scroll-lock'), use `variable-pitch-mode' in non-programming
 ;; buffers (`logos-variable-pitch'), make the buffer read-only
 ;; (`logos-buffer-read-only'), center the buffer in its window if the
@@ -81,7 +82,7 @@
 ;; backronyms about the mechanics of this package:
 ;;
 ;; 1. `^L' Only Generates Ostensible Slides
-;; 2. Logos Optionally Garners Outline Sections
+;; 2. Logos Optionally Goes through Outline Sections
 ;;
 ;;
 ;; Consult the manual for all sorts of tweaks and extras:
@@ -113,7 +114,7 @@ When this variable is nil, pages are demarcated by the
   `((emacs-lisp-mode . "^;;;+ ")
     (org-mode . "^\\*+ +")
     (markdown-mode . "^\\#+ +")
-    (t . ,(or outline-regexp logos--page-delimiter)))
+    (t . ,(if (boundp 'outline-regexp) outline-regexp logos--page-delimiter)))
   "Alist of major mode and regular expression of the outline.
 Only used when `logos-outlines-are-pages' is non-nil.
 
@@ -125,6 +126,14 @@ the latter."
   :package-version '(logos . "0.1.0")
   :group 'logos)
 
+(defcustom logos-hide-cursor nil
+  "When non-nil hide the cursor.
+This is only relevant when `logos-focus-mode' is enabled."
+  :type 'boolean
+  :group 'logos
+  :package-version '(logos . "1.0.0")
+  :local t)
+
 (defcustom logos-hide-mode-line nil
   "When non-nil hide the modeline.
 This is only relevant when `logos-focus-mode' is enabled."
@@ -191,7 +200,7 @@ This is only relevant when `logos-focus-mode' is enabled."
   :local t)
 
 (defcustom logos-focus-mode-extra-functions nil
-  "List of functions to execute when `logos-focus-mode' is toggled.
+  "List of functions to execute when `logos-focus-mode' is enabled.
 
 Each function is run without an argument.  An example that sets a
 variable is `logos--buffer-read-only'; one that sets a mode is
@@ -199,7 +208,11 @@ variable is `logos--buffer-read-only'; one that sets a mode is
 package is `logos--olivetti'; while `logos--hide-fringe' provides
 yet another useful sample.
 
-Consult the Logos manual for concrete do-it-yourself examples."
+Consult the Logos manual for concrete do-it-yourself examples.
+
+If a function cannot be like the aforementioned though still
+needs to set its state both when `logos-focus-mode' is enabled
+and disabled, then use the `logos-focus-mode-hook' instead."
   :type 'hook
   :package-version '(logos . "0.4.0")
   :group 'logos)
@@ -405,12 +418,14 @@ alternate, thus toggling MODE."
 (put #'logos-forward-page-dwim 'repeat-map 'logos-repeat-map)
 (put #'logos-backward-page-dwim 'repeat-map 'logos-repeat-map)
 
+;;;###autoload
 (define-minor-mode logos-focus-mode
   "Buffer-local mode for focused editing.
 When enabled it sets the buffer-local value of these user
 options: `logos-scroll-lock', `logos-variable-pitch',
-`logos-hide-mode-line', `logos-hide-buffer-boundaries',
-`logos-buffer-read-only', `logos-olivetti', `logos-hide-fringe'."
+`logos-hide-cursor', `logos-hide-mode-line',
+`logos-hide-buffer-boundaries', `logos-buffer-read-only',
+`logos-olivetti', `logos-hide-fringe'."
   :init-value nil
   :global nil
   :keymap logos-focus-mode-map
@@ -429,6 +444,7 @@ options: `logos-scroll-lock', `logos-variable-pitch',
   (logos--scroll-lock)
   (logos--olivetti)
   ;; variables
+  (logos--hide-cursor)
   (logos--hide-mode-line)
   (logos--indicate-buffer-boundaries)
   (logos--buffer-read-only)
@@ -450,6 +466,11 @@ options: `logos-scroll-lock', `logos-variable-pitch',
   (when logos-hide-buffer-boundaries
     (logos--set 'indicate-buffer-boundaries nil)))
 
+(defun logos--hide-cursor ()
+  "Set `logos-hide-cursor'."
+  (when logos-hide-cursor
+    (logos--set 'cursor-type nil)))
+
 ;; FIXME 2022-03-13: The mode line is not redrawn properly.  Not even
 ;; with `force-mode-line-update', unless something happens like
 ;; switching to the other window.  Using `redisplay' does not fix the
@@ -485,8 +506,8 @@ options: `logos-scroll-lock', `logos-variable-pitch',
 (defun logos--hide-fringe ()
   "Set buffer-local `fringe' to the same background as `default'."
   (when logos-hide-fringe
-      (setq logos--fringe-remap-cookie
-            (face-remap-add-relative 'fringe :background (face-background 'default)))))
+    (setq logos--fringe-remap-cookie
+          (face-remap-add-relative 'fringe :background (face-background 'default)))))
 
 (defun logos--remove-fringe-remap ()
   "Remove effect of `logos--hide-fringe'."
